From: Julian Ospald <hasufell@gentoo.org>
Date: Fri Jun 15 21:58:45 UTC 2012

use proper destinations and allow Gentoo build type
rename demo targets to avoid confusion

--- CMake/Utils/MyGUIConfigTargets.cmake
+++ CMake/Utils/MyGUIConfigTargets.cmake
@@ -1,6 +1,8 @@
 # Configure settings and install targets
 # FIXME: Copypasted from Ogre and need lots of changes
 
+include(GNUInstallDirs)
+
 if (WIN32)
 	set(MYGUI_RELEASE_PATH "/Release")
 	set(MYGUI_RELWDBG_PATH "/RelWithDebInfo")
@@ -56,6 +58,12 @@
 # install targets according to current build type
 function(mygui_install_target TARGETNAME SUFFIX)
 	install(TARGETS ${TARGETNAME}
+		RUNTIME DESTINATION "${CMAKE_INSTALL_BINDIR}" CONFIGURATIONS Gentoo ""
+		LIBRARY DESTINATION "${CMAKE_INSTALL_LIBDIR}" CONFIGURATIONS Gentoo ""
+		ARCHIVE DESTINATION "${CMAKE_INSTALL_LIBDIR}" CONFIGURATIONS Gentoo ""
+		FRAMEWORK DESTINATION "${MYGUI_FRAMEWORK_PATH}" CONFIGURATIONS Gentoo ""
+	)
+	install(TARGETS ${TARGETNAME}
 		RUNTIME DESTINATION "bin${MYGUI_RELEASE_PATH}" CONFIGURATIONS Release None ""
 		LIBRARY DESTINATION "lib${MYGUI_LIB_RELEASE_PATH}${SUFFIX}" CONFIGURATIONS Release None ""
 		ARCHIVE DESTINATION "lib${MYGUI_LIB_RELEASE_PATH}${SUFFIX}" CONFIGURATIONS Release None ""
@@ -170,7 +178,13 @@
 		endif ()
 		add_executable(${PROJECTNAME} ${MYGUI_EXEC_TYPE} ${HEADER_FILES} ${SOURCE_FILES})
 	endif ()
-	set_target_properties(${PROJECTNAME} PROPERTIES FOLDER ${SOLUTIONFOLDER})
+
+	# rename demo target
+	if (${SOLUTIONFOLDER} STREQUAL "Demos")
+		set_target_properties(${PROJECTNAME} PROPERTIES FOLDER ${SOLUTIONFOLDER} OUTPUT_NAME MYGUI-${PROJECTNAME})
+	else()
+		set_target_properties(${PROJECTNAME} PROPERTIES FOLDER ${SOLUTIONFOLDER})
+	endif()
 	
 	add_dependencies(${PROJECTNAME} MyGUIEngine Common)
 
@@ -326,4 +340,4 @@
 			INSTALL_RPATH ${CMAKE_INSTALL_PREFIX}/lib)
 		set_property(TARGET ${PROJECTNAME} PROPERTY INSTALL_RPATH_USE_LINK_PATH TRUE)
 	endif ()
-endfunction(mygui_config_sample)
\ No newline at end of file
+endfunction(mygui_config_sample)
--- CMake/ConfigureBuild.cmake
+++ CMake/ConfigureBuild.cmake
@@ -4,6 +4,8 @@
 # also prepare package files for pkg-config and CMake.
 #######################################################################
 
+include(GNUInstallDirs)
+
 # should we build static libs?
 if (MYGUI_STATIC)
   set(MYGUI_LIB_TYPE STATIC)
@@ -47,7 +49,7 @@
   else ()
     configure_file(${MYGUI_TEMPLATES_DIR}/MYGUI.pc.in ${MYGUI_BINARY_DIR}/pkgconfig/MYGUI${MYGUI_LIB_SUFFIX}.pc @ONLY)
   endif ()
-  install(FILES ${MYGUI_BINARY_DIR}/pkgconfig/MYGUI${MYGUI_LIB_SUFFIX}.pc DESTINATION lib/pkgconfig)
+  install(FILES ${MYGUI_BINARY_DIR}/pkgconfig/MYGUI${MYGUI_LIB_SUFFIX}.pc DESTINATION ${CMAKE_INSTALL_LIBDIR}/pkgconfig)
 
   # configure additional packages
   
